
package pa195.ispn;

import org.infinispan.Cache;
import org.infinispan.manager.DefaultCacheManager;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Example code for course PA195 @ FI MUNI
 * 
 * Creates an embedded Infinispan (Ispn) store and puts all students from given file 
 *  to this store.
 * 
 * @author David Novak, Masaryk University, Brno, Czech Republic, david.novak@fi.muni.cz
 */
public class Students {
    
    public static void main(String args []) {
        Cache<String, String> store = null;
        try {
            File sourceFile = new File("/Users/david/tmp/seznam_export.csv");
            if (! sourceFile.canRead()) {
                System.err.println("File " + sourceFile.getAbsolutePath() + " cannot be read.");
                return;
            }

            store = new DefaultCacheManager("src/main/resources/ispn-config.xml").getCache();
            //store = new DefaultCacheManager().getCache();
                        
            if (printAllKeyValues(store)) {
                return;
            }
            
            // read the text file with exported data
            try (BufferedReader fileReader = new BufferedReader(new FileReader(sourceFile))) {
                while (fileReader.ready()) {
                    String value = fileReader.readLine();
                    String key = value.split(";")[0];
                    store.put(key, value);

                    System.out.println("Successfully stored student '" + key + "': " + value);
                }
            }            
        } catch (IOException ex) {
            Logger.getLogger(Students.class.getName()).log(Level.SEVERE, null, ex);
        } finally {
            if (store != null) {
                store.stop();
            }
        }
    }

    /**
     * 
     * @param ispnStore
     * @return true if the store was not empty
     */
    protected static boolean printAllKeyValues(Cache<String, String> ispnStore) {
        System.out.println("printing current data in the Ispn store: ");
        boolean retVal = false;
        for (Map.Entry<String, String> entry : ispnStore.entrySet()) {
            System.out.println(entry.getKey()+": "+entry.getValue());
            retVal = true;
        }
        return retVal;
    }
    
}
